%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% DemoQBiPerHelmholtzG
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%
% Overview:
%   Plot the periodic Green's function for the Laplace
%   equation.
%
% Reference:
%   Section 2.13.5
%   Mathematical and Computational Methods in Photonics and Phononics
%
% Authors:
%   Habib Ammari, Brian Fitzpatrick, Hyeonbae Kang,
%   Matias Ruiz, Sanghyeon Yu, Hai Zhang
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
xMax = 5;
nX = 2^8;
hX = 2*xMax/(nX-1);
[x1, x2] = meshgrid(-xMax:hX:xMax);
d1 = 1;
d2 = 1;
k = 2;

alpha = [0, pi/8];

G = ops.GBiPeriodic(k, x1, x2, d1, d2, alpha);

hFig = figure(1);
set(hFig, 'Position', [100 100 1400 900])
subplot(1, 2, 1);
surf(x1, x2, real(G), 'edgecolor', 'none');
xlabel('x_1'); ylabel('x_2'); zlabel('G')
title('Re(G^{\alpha, \omega})')
view([0 0 90]); rotate3d on; colormap jet;

subplot(1, 2, 2);
surf(x1, x2, imag(G), 'edgecolor', 'none');
xlabel('x_1'); ylabel('x_2'); zlabel('G')
title('Im(G^{\alpha, \omega})')
view([0 0 90]); rotate3d on; colormap jet;